@@ -41,11 +41,11 @@ private:
     static void autoHidingPanelShownCallback(void *data, org_kde_plasma_surface *org_kde_plasma_surface);
 
     PlasmaShellSurface *q;
-    static QVector<Private *> s_surfaces;
+    static QList<Private *> s_surfaces;
     static const org_kde_plasma_surface_listener s_listener;
 };
 
-QVector<PlasmaShellSurface::Private *> PlasmaShellSurface::Private::s_surfaces;
+QList<PlasmaShellSurface::Private *> PlasmaShellSurface::Private::s_surfaces;
 
 PlasmaShell::PlasmaShell(QObject *parent)
     : QObject(parent)
@@ -239,6 +239,11 @@ void PlasmaShellSurface::setPosition(const QPoint &point)
     org_kde_plasma_surface_set_position(d->surface, point.x(), point.y());
 }
 
+void PlasmaShellSurface::openUnderCursor()
+{
+    org_kde_plasma_surface_open_under_cursor(d->surface);
+}
+
 void PlasmaShellSurface::setRole(PlasmaShellSurface::Role role)
 {
     Q_ASSERT(isValid());
@@ -270,6 +275,15 @@ void PlasmaShellSurface::setRole(PlasmaShellSurface::Role role)
             wlRole = ORG_KDE_PLASMA_SURFACE_ROLE_CRITICALNOTIFICATION;
         }
         break;
+    case Role::AppletPopup:
+        if (wl_proxy_get_version(d->surface) < ORG_KDE_PLASMA_SURFACE_ROLE_APPLETPOPUP_SINCE_VERSION) {
+            // dock is what applet popups were before
+            wlRole = ORG_KDE_PLASMA_SURFACE_ROLE_PANEL;
+            setPanelBehavior(PanelBehavior::WindowsGoBelow);
+        } else {
+            wlRole = ORG_KDE_PLASMA_SURFACE_ROLE_APPLETPOPUP;
+        }
+        break;
     default:
         Q_UNREACHABLE();
         break;
@@ -334,3 +348,5 @@ void PlasmaShellSurface::setPanelTakesFocus(bool takesFocus)
 
 }
 }
+
+#include "moc_plasmashell.cpp"
